==> SyL-0.14.0.tar.gz: SyL/include/framework/Auth/SyL_AuthConfig.php <==
<?php
/**
 * -----------------------------------------------------------------------------
 *
 * SyL - Web Application Framework for PHP
 *
 * PHP version 4 (>= 4.3.x) or 5
 *
 * Copyright (C) 2006-2007 k.watanabe
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * -----------------------------------------------------------------------------
 * @package   SyL
 * @author    Koki Watanabe <k.watanabe@syl.jp>
 * @copyright 2006-2007 k.watanabe
 * @license   http://www.opensource.org/licenses/lgpl-license.php
 * @version   CVS: $Id: SyL_AuthConfig.php,v 1.1 2007/08/12 05:59:50 seasonstream Exp $
 * @link      http://www.syl.jp/
 * -----------------------------------------------------------------------------
 */

/**
 * defines.xmlǧڥ饹
 *
 * @package   SyL
 * @author    Koki Watanabe <k.watanabe@syl.jp>
 * @copyright 2006-2007 k.watanabe
 * @license   http://www.opensource.org/licenses/lgpl-license.php
 * @version   CVS: $Id: SyL_AuthConfig.php,v 1.1 2007/08/12 05:59:50 seasonstream Exp $
 * @link      http://www.syl.jp/
 */
class SyL_AuthConfig extends SyL_Auth
{
    /**
     * ǧڼ¹
     * 
     * @access public
     * @return bool OK: ǧOK, NG: ǧNG
     */
    function doLogin()
    {
         $client_username = isset($_POST[$this->username]) ? $_POST[$this->username] : '';
         $client_password = isset($_POST[$this->password]) ? $_POST[$this->password] : '';

         $server_password = null;
         foreach (explode(';', SYL_AUTH_TYPE_PARAMETER) as $user) {
             $user = explode(':', $user, 2);
             if ($user[0] && ($user[0] == $client_username)) {
                 $server_password = $user[1];
                 break;
             }
         }

         if ($server_password === null) {
             // ǧԲ
             $client_username = '';
             $server_password = '';
         }
         // ѥȽ
         return $this->isLoginPassword($client_username, $client_password, $server_password);
    }
}

?>

==> SyL-0.14.1.tar.gz: SyL/include/framework/Auth/SyL_AuthConfig.php <==
<?php
/**
 * -----------------------------------------------------------------------------
 *
 * SyL - Web Application Framework for PHP
 *
 * PHP version 4 (>= 4.3.x) or 5
 *
 * Copyright (C) 2006-2007 k.watanabe
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * -----------------------------------------------------------------------------
 * @package   SyL
 * @author    Koki Watanabe <k.watanabe@syl.jp>
 * @copyright 2006-2007 k.watanabe
 * @license   http://www.opensource.org/licenses/lgpl-license.php
 * @version   CVS: $Id: SyL_AuthConfig.php,v 1.2 2007/09/02 14:40:34 seasonstream Exp $
 * @link      http://www.syl.jp/
 * -----------------------------------------------------------------------------
 */

/**
 * defines.xmlǧڥ饹
 *
 * @package   SyL
 * @author    Koki Watanabe <k.watanabe@syl.jp>
 * @copyright 2006-2007 k.watanabe
 * @license   http://www.opensource.org/licenses/lgpl-license.php
 * @version   CVS: $Id: SyL_AuthConfig.php,v 1.2 2007/09/02 14:40:34 seasonstream Exp $
 * @link      http://www.syl.jp/
 */
class SyL_AuthConfig extends SyL_Auth
{
    /**
     * ǧڼ¹
     * 
     * @access public
     * @return bool OK: ǧOK, NG: ǧNG
     */
    function doLogin()
    {
        list($id, $passwd) = $this->getLoginParameterName();
        $client_username = isset($_POST[$id])     ? $_POST[$id]     : '';
        $client_password = isset($_POST[$passwd]) ? $_POST[$passwd] : '';

        $server_password = null;
        foreach (explode(';', SYL_AUTH_TYPE_PARAMETER) as $user) {
            $user = explode(':', $user, 2);
            if ($user[0] && ($user[0] == $client_username)) {
                $server_password = $user[1];
                break;
            }
        }

        if ($server_password === null) {
            // ǧԲ
            $client_username = '';
            $server_password = '';
        }
        // ѥȽ
        return $this->isLoginPassword($client_username, $client_password, $server_password);
    }
}

?>
